==> afnix_2.5.1.orig.tar.gz: afnix-src-2.5.1/src/srv/phy/shl/PhyCalls.hpp <==
// ---------------------------------------------------------------------------
// - PhyCalls.hpp                                                            -
// - afnix:phy service - physics specific calls definitions                  -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2015 amaury darsch                                   -
// ---------------------------------------------------------------------------

#ifndef  AFNIX_PHYCALLS_HPP
#define  AFNIX_PHYCALLS_HPP

#ifndef  AFNIX_OBJECT_HPP
#include "Object.hpp"
#endif
 
namespace afnix {

  /// This file contains specific system procedures that require only
  /// arguments and that are not bounded to a class
  /// @author amaury darsch

  /// compute the thermal voltage by temperature
  /// @param robj the current runnable
  /// @param nset the current nameset
  /// @param args the argument list
  Object* phy_getvth (Runnable* robj, Nameset* nset, Cons* args);
}


#endif

==> afnix_3.3.0.orig.tar.gz: afnix-src-3.3.0/src/srv/phy/shl/PhyCalls.hpp <==
// ---------------------------------------------------------------------------
// - PhyCalls.hpp                                                            -
// - afnix:phy service - physics specific calls definitions                  -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2020 amaury darsch                                   -
// ---------------------------------------------------------------------------

#ifndef  AFNIX_PHYCALLS_HPP
#define  AFNIX_PHYCALLS_HPP

#ifndef  AFNIX_OBJECT_HPP
#include "Object.hpp"
#endif
 
namespace afnix {

  /// This file contains specific system procedures that require only
  /// arguments and that are not bounded to a class
  /// @author amaury darsch

  /// create a unit by name
  /// @param zobj the current evaluable
  /// @param nset the current nameset
  /// @param args the argument list
  Object* phy_tounit (Evaluable* zobj, Nameset* nset, Cons* args);

  /// create a physical constant by name
  /// @param zobj the current evaluable
  /// @param nset the current nameset
  /// @param args the argument list
  Object* phy_tophys (Evaluable* zobj, Nameset* nset, Cons* args);
}


#endif
